@@ -1,4 +1,4 @@
-"""Function decorator for ZnTrack"""
+"""Function decorator for ZnTrack."""
 import copy
 import dataclasses
 import logging
@@ -23,7 +23,7 @@ UnionDictListOfStrPath = typing.Union[
 
 @dataclasses.dataclass
 class NodeConfig:
-    """DataClass to contain the arguments passed by the user
+    """DataClass to contain the arguments passed by the user.
 
     Attributes
     ----------
@@ -43,35 +43,35 @@ class NodeConfig:
     plots_no_cache: UnionDictListOfStrPath = None
 
     def __post_init__(self):
-        for option_name in self.__dataclass_fields__:
+        """dataclass post_init."""
+        for datacls_field in dataclasses.fields(self):
             # type checking
-            option_value = getattr(self, option_name)
-            if option_name == "params":
+            option_value = getattr(self, datacls_field.name)
+            if datacls_field.name == "params":
                 # params does not have to be a string
                 if not isinstance(option_value, dict) and option_value is not None:
                     raise ValueError("Parameter must be dict or dot4dict.dotdict.")
-            else:
-                if not utils.check_type(
-                    option_value,
-                    (str, pathlib.Path),
-                    allow_iterable=True,
-                    allow_none=True,
-                    allow_dict=True,
-                ):
-                    raise ValueError(
-                        f"{option_value} is not a supported type. "
-                        "Please use single values or lists of <str> and <pathlib.Path>."
-                    )
+            elif not utils.check_type(
+                option_value,
+                (str, pathlib.Path),
+                allow_iterable=True,
+                allow_none=True,
+                allow_dict=True,
+            ):
+                raise ValueError(
+                    f"{option_value} is not a supported type. "
+                    "Please use single values or lists of <str> and <pathlib.Path>."
+                )
 
     def convert_fields_to_dotdict(self):
-        """Update all fields to dotdict, if they are of type dict"""
-        for option_name in self.__dataclass_fields__:
-            option_value = getattr(self, option_name)
+        """Update all fields to dotdict, if they are of type dict."""
+        for datacls_field in dataclasses.fields(self):
+            option_value = getattr(self, datacls_field.name)
             if isinstance(option_value, dict):
-                setattr(self, option_name, dot4dict.dotdict(option_value))
+                setattr(self, datacls_field.name, dot4dict.dotdict(option_value))
 
     def write_dvc_command(self, node_name: str) -> list:
-        """Collect dvc commands
+        """Collect dvc commands.
 
         Parameters
         ----------
@@ -86,28 +86,27 @@ class NodeConfig:
 
         """
         script = []
-        if self.params is not None:
-            if len(self.params) > 0:
-                script += ["--params", f"{utils.Files.params}:{node_name}"]
-        for field in self.__dataclass_fields__:
-            if field == "params":
+        if self.params is not None and len(self.params) > 0:
+            script += ["--params", f"{utils.Files.params}:{node_name}"]
+        for datacls_field in dataclasses.fields(self):
+            if datacls_field.name == "params":
                 continue
-            if isinstance(getattr(self, field), (list, tuple)):
-                for element in getattr(self, field):
+            if isinstance(getattr(self, datacls_field.name), (list, tuple)):
+                for element in getattr(self, datacls_field.name):
                     script += [
-                        f"--{field.replace('_', '-')}",
+                        f"--{datacls_field.name.replace('_', '-')}",
                         pathlib.Path(element).as_posix(),
                     ]
-            elif isinstance(getattr(self, field), dict):
-                for element in getattr(self, field).values():
+            elif isinstance(getattr(self, datacls_field.name), dict):
+                for element in getattr(self, datacls_field.name).values():
                     script += [
-                        f"--{field.replace('_', '-')}",
+                        f"--{datacls_field.name.replace('_', '-')}",
                         pathlib.Path(element).as_posix(),
                     ]
-            elif getattr(self, field) is not None:
+            elif getattr(self, datacls_field.name) is not None:
                 script += [
-                    f"--{field.replace('_', '-')}",
-                    pathlib.Path(getattr(self, field)).as_posix(),
+                    f"--{datacls_field.name.replace('_', '-')}",
+                    pathlib.Path(getattr(self, datacls_field.name)).as_posix(),
                 ]
 
         return script
@@ -117,7 +116,7 @@ AnyOrNodeConfig = typing.Union[typing.Any, NodeConfig]
 
 
 def execute_function_call(func):
-    """Run the function call
+    """Run the function call.
 
     1. Load the parameters from the Files.zntrack / Files.params
     2. Deserialize them
@@ -126,7 +125,8 @@ def execute_function_call(func):
 
     Parameters
     ----------
-    func: decorated function
+    func: callable
+        decorated function
 
     Returns
     -------
@@ -146,7 +146,7 @@ def execute_function_call(func):
 
 
 def save_node_config_to_files(cfg: NodeConfig, node_name: str):
-    """Save the values from cfg to zntrack.json / params.yaml
+    """Save the values from cfg to zntrack.json / params.yaml.
 
     Parameters
     ----------
@@ -185,10 +185,10 @@ def nodify(
     plots: UnionDictListOfStrPath = None,
     plots_no_cache: UnionDictListOfStrPath = None,
 ):
-    """Main wrapper Function to convert a function into a DVC Stage
+    """Main wrapper Function to convert a function into a DVC Stage.
 
-    Parameters
-    ----------
+    Special Parameters
+    ------------------
     params: dict
         for the params.yaml file context
     **kwargs: str|Path|list
@@ -213,7 +213,7 @@ def nodify(
     )
 
     def func_collector(func):
-        """Required for decorator to work"""
+        """Required for decorator to work."""
 
         def wrapper(
             *,
@@ -229,7 +229,7 @@ def nodify(
             run: bool = None,
             exec_func=False,
         ) -> AnyOrNodeConfig:
-            """Wrap the function
+            """Wrap the function.
 
             Parameters
             ----------
@@ -240,13 +240,20 @@ def nodify(
                 subprocess call.
             nb_name: str
                 Notebook name when not using config.nb_name (this is not recommended)
-            no_commit: dvc parameter
-            external: dvc parameter
-            always_changed: dvc parameter
-            no_exec: dvc parameter
-            run: bool, inverse of no_exec. Will overwrite no_exec if set.
-            force: dvc parameter
-            no_run_cache: dvc parameter
+            no_commit:
+                dvc parameter
+            external:
+                dvc parameter
+            always_changed:
+                dvc parameter
+            no_exec:
+                dvc parameter
+            run: bool,
+                inverse of no_exec. Will overwrite no_exec if set.
+            force:
+                dvc parameter
+            no_run_cache:
+                dvc parameter
             dry_run: bool, default = False
                 Only return the script but don't actually run anything
 
@@ -278,33 +285,35 @@ def nodify(
             if exec_func:
                 return execute_function_call(func)
 
-            else:
-                cfg = copy.deepcopy(cfg_)
-                save_node_config_to_files(cfg=cfg, node_name=func.__name__)
-                dvc_run_option = DVCRunOptions(
-                    no_commit=no_commit,
-                    external=external,
-                    always_changed=always_changed,
-                    no_run_cache=no_run_cache,
-                    no_exec=no_exec,
-                    force=force,
-                )
+            cfg = copy.deepcopy(cfg_)
+            save_node_config_to_files(cfg=cfg, node_name=func.__name__)
+            dvc_run_option = DVCRunOptions(
+                no_commit=no_commit,
+                external=external,
+                always_changed=always_changed,
+                no_run_cache=no_run_cache,
+                force=force,
+            )
 
-                script = prepare_dvc_script(
-                    node_name=func.__name__,
-                    dvc_run_option=dvc_run_option,
-                    custom_args=cfg.write_dvc_command(func.__name__),
-                    nb_name=nb_name,
-                    module=module,
-                    func_or_cls=func.__name__,
-                    call_args="(exec_func=True)",
-                )
+            script = prepare_dvc_script(
+                node_name=func.__name__,
+                dvc_run_option=dvc_run_option,
+                custom_args=cfg.write_dvc_command(func.__name__),
+                nb_name=nb_name,
+                module=module,
+                func_or_cls=func.__name__,
+                call_args="(exec_func=True)",
+            )
 
-                if dry_run:
-                    return script
-                utils.run_dvc_cmd(script)
-                cfg.convert_fields_to_dotdict()
-                return cfg
+            if dry_run:
+                return script
+            utils.run_dvc_cmd(script)
+
+            if not no_exec:
+                utils.run_dvc_cmd(["repro", func.__name__])
+
+            cfg.convert_fields_to_dotdict()
+            return cfg
 
         return wrapper
 
