@@ -1,9 +1,11 @@
-"""Standard python init file for the utils directory"""
+"""Standard python init file for the utils directory."""
 
-from zntrack.utils import exceptions, file_io
+from zntrack.utils import exceptions, file_io, helpers
 from zntrack.utils.config import Files, config
+from zntrack.utils.nwd import nwd
 from zntrack.utils.structs import (
     FILE_DVC_TRACKED,
+    GIT_TRACKED,
     VALUE_DVC_TRACKED,
     DVCOptions,
     LazyOption,
@@ -15,11 +17,10 @@ from zntrack.utils.utils import (
     decode_dict,
     deprecated,
     encode_dict,
-    get_auto_init,
-    get_python_interpreter,
     module_handler,
     module_to_path,
     run_dvc_cmd,
+    update_gitignore,
     update_nb_name,
 )
 
@@ -37,11 +38,13 @@ __all__ = [
     "exceptions",
     Files.__name__,
     "check_type",
-    "get_python_interpreter",
     "run_dvc_cmd",
-    "get_auto_init",
     "FILE_DVC_TRACKED",
     "VALUE_DVC_TRACKED",
     "DVCOptions",
     "LazyOption",
+    "helpers",
+    "nwd",
+    "GIT_TRACKED",
+    "update_gitignore",
 ]
