@@ -1,3 +1,6 @@
+"""ZnTrack utils."""
+
+import contextlib
 import json
 import logging
 import os
@@ -6,8 +9,9 @@ import shutil
 import subprocess
 import sys
 import tempfile
-import typing
 
+import dvc.cli
+import git
 import znjson
 
 from zntrack.utils.config import config
@@ -17,7 +21,7 @@ log = logging.getLogger(__name__)
 
 
 def cwd_temp_dir(required_files=None) -> tempfile.TemporaryDirectory:
-    """Change into a temporary directory
+    """Change into a temporary directory.
 
     Helper for e.g. the docs to quickly change into a temporary directory
     and copy all files, e.g. the Notebook into that directory.
@@ -33,10 +37,15 @@ def cwd_temp_dir(required_files=None) -> tempfile.TemporaryDirectory:
         The temporary  directory file. Close with temp_dir.cleanup() at the end.
 
     """
-    temp_dir = tempfile.TemporaryDirectory()  # add ignore_cleanup_errors=True in Py3.10?
+    temp_dir = tempfile.TemporaryDirectory()  # pylint: disable=consider-using-with
+    # add ignore_cleanup_errors=True in Py3.10?
 
     if config.nb_name is not None:
         shutil.copy(config.nb_name, temp_dir.name)
+        if config.dvc_api:
+            # TODO: why is this required?
+            log.debug("Setting 'config.dvc_api=False' for use in Jupyter Notebooks.")
+            config.dvc_api = False
     if required_files is not None:
         for file in required_files:
             shutil.copy(file, temp_dir.name)
@@ -47,7 +56,7 @@ def cwd_temp_dir(required_files=None) -> tempfile.TemporaryDirectory:
 
 
 def deprecated(reason, version="v0.0.0"):
-    """Depreciation Warning"""
+    """Depreciation Warning."""
 
     def decorator(func):
         def wrapper(*args, **kwargs):
@@ -63,44 +72,17 @@ def deprecated(reason, version="v0.0.0"):
 
 
 def decode_dict(value):
-    """Decode dict that was loaded without znjson"""
+    """Decode dict that was loaded without znjson."""
     return json.loads(json.dumps(value), cls=znjson.ZnDecoder)
 
 
 def encode_dict(value) -> dict:
-    """Encode value into a dict serialized with ZnJson"""
+    """Encode value into a dict serialized with ZnJson."""
     return json.loads(json.dumps(value, cls=znjson.ZnEncoder))
 
 
-def get_auto_init(fields: typing.List[str], super_init: typing.Callable):
-    """Automatically create an __init__ based on fields
-
-    Parameters
-    ----------
-    fields: list[str]
-        A list of strings that will be used in the __init__, e.g. for [foo, bar]
-        it will create __init__(self, foo=None, bar=None) using **kwargs
-    super_init: Callable
-        typically this is Node.__init__
-    """
-
-    def auto_init(self, **kwargs):
-        """Wrapper for the __init__"""
-        for field in fields:
-            try:
-                setattr(self, field, kwargs.pop(field))
-            except KeyError:
-                pass
-        super_init(self, **kwargs)  # call the super_init explicitly instead of super
-
-    # we add this attribute to the __init__ to make it identifiable
-    auto_init._uses_auto_init = True
-
-    return auto_init
-
-
 def module_handler(obj) -> str:
-    """Get the module for the Node
+    """Get the module for the Node.
 
     There are three cases that have to be handled here:
         1. Run from __main__ should not have __main__ as module but
@@ -114,30 +96,34 @@ def module_handler(obj) -> str:
     obj:
         Any object that implements __module__
     """
-    if obj.__module__ == "__main__":
-        if pathlib.Path(sys.argv[0]).stem == "ipykernel_launcher":
-            # special case for e.g. testing
-            return obj.__module__
-        return pathlib.Path(sys.argv[0]).stem
-    else:
+    if obj.__module__ != "__main__":
         return obj.__module__
+    if pathlib.Path(sys.argv[0]).stem == "ipykernel_launcher":
+        # special case for e.g. testing
+        return obj.__module__
+    return pathlib.Path(sys.argv[0]).stem
 
 
 def check_type(
     obj, types, allow_iterable=False, allow_none=False, allow_dict=False
 ) -> bool:
-    """Check if the obj is of any of the given types
+    """Check if the obj is of the given types.
 
     This includes recursive search for nested lists / dicts and fails
     if any of the values is not in types
 
     Parameters
     ----------
-    obj: object to check
-    types: single class or tuple of classes to check against
-    allow_iterable: check list entries if a list is provided
-    allow_none: accept None even if not in types.
-    allow_dict: allow for {key: types}
+    obj:
+        object to check
+    types:
+        single class or tuple of classes to check against
+    allow_iterable:
+        check list entries if a list is provided
+    allow_none:
+        accept None even if not in types.
+    allow_dict:
+        allow for {key: types}
     """
     if isinstance(obj, (list, tuple, set)) and allow_iterable:
         for value in obj:
@@ -159,104 +145,102 @@ def check_type(
 
 
 def update_nb_name(nb_name: str) -> str:
-    """Check the config file for a nb_name if None provided"""
+    """Check the config file for a nb_name if None provided."""
     if nb_name is None:
         return config.nb_name
     return nb_name
 
 
 def module_to_path(module: str, suffix=".py") -> pathlib.Path:
-    """convert module a.b.c to path(a/b/c)"""
+    """Convert module a.b.c to path(a/b/c)."""
     return pathlib.Path(*module.split(".")).with_suffix(suffix)
 
 
-def get_python_interpreter() -> str:
-    """Find the most suitable python interpreter
-
-    Try to run subprocess check calls to see, which python interpreter
-    should be selected
-
-    Returns
-    -------
-    interpreter: str
-        Name of the python interpreter that works with subprocess calls
-
-    """
-
-    for interpreter in ["python3", "python"]:
-        try:
-            subprocess.check_call(
-                [interpreter, "--version"],
-                stdout=subprocess.DEVNULL,
-                stderr=subprocess.DEVNULL,
-            )
-            log.debug(f"Using command {interpreter} for dvc!")
-            return interpreter
-
-        except subprocess.CalledProcessError:
-            log.debug(f"{interpreter} is not working!")
-        except FileNotFoundError as err:
-            log.debug(err)
-    raise ValueError(
-        "Could not find a working python interpreter to work with subprocesses!"
-    )
-
-
 def run_dvc_cmd(script):
-    """Run the DVC script via subprocess calls
+    """Run the DVC script via subprocess calls.
 
     Parameters
     ----------
-    script: list[str]
+    script: tuple[str]|list[str]
         A list of strings to pass the subprocess command
 
+    Raises
+    ------
+    DVCProcessError:
+        if the dvc cli command fails
+
     """
-    dvc_short_string = " ".join(script[:4])
-    if len(script) > 4:
+    dvc_short_string = " ".join(script[:5])
+    if len(script) > 5:
         dvc_short_string += " ..."
     log.warning(f"Running DVC command: '{dvc_short_string}'")
-    try:
-        # do not display the output if log.log_level > logging.INFO
-        subprocess.run(script, check=True, capture_output=config.log_level > logging.INFO)
-    except subprocess.CalledProcessError as err:
-        raise DVCProcessError(
-            f"Subprocess call with cmd: \n \"{' '.join(script)}\" \n"
-            f"# failed after stdout: \n{err.stdout.decode()}"
-            f"# with stderr: \n{err.stderr.decode()}"
-        ) from err
+    # do not display the output if log.log_level > logging.INFO
+    show_log = config.log_level < logging.INFO
+    if not show_log:
+        script = script[:2] + ["--quiet"] + script[2:]
+    if config.log_level == logging.DEBUG:
+        script = [x for x in script if x != "--quiet"]
+        script = script[:2] + ["--verbose", "--verbose"] + script[2:]
+
+    if config.dvc_api:
+        return_code = dvc.cli.main(script)
+        if return_code != 0:
+            raise DVCProcessError(
+                f"DVC CLI failed ({return_code}) for cmd: \n \"{' '.join(script)}\" "
+            )
+        # fix for https://github.com/iterative/dvc/issues/8631
+        for logger_name, logger in logging.root.manager.loggerDict.items():
+            if logger_name.startswith("zntrack"):
+                logger.disabled = False
+        return return_code
+    else:
+        script = ["dvc"] + script
+        try:
+            # do not display the output if log.log_level > logging.INFO
+            output = subprocess.run(script, check=True, capture_output=True)
+            log.info(output.stdout.decode())
+        except subprocess.CalledProcessError as err:
+            raise DVCProcessError(
+                f"Subprocess call with cmd: \n \"{' '.join(script)}\" \n"
+                f"# failed after stdout: \n{err.stdout.decode()}"
+                f"# with stderr: \n{err.stderr.decode()}"
+            ) from err
 
 
-def load_node_dependency(value, log_warning=False):
-    """Load a Node dependency if passed only a class
+def load_node_dependency(value):
+    """Load a Node dependency if passed only a class.
 
     Parameters
     ----------
     value: anything
         This function creates an instance of value if it is a class of node. Otherwise,
         it does nothing.
-    log_warning: bool
-        Log a DepreciationWarning when used from dvc.deps()
 
     Returns
     -------
     value:
         If value was subclass of Node, it returns an instance of value, otherwise
         it returns value
-
     """
     from zntrack.core.base import Node
 
     if isinstance(value, (list, tuple)):
-        value = [load_node_dependency(x, log_warning) for x in value]
-    try:
+        value = [load_node_dependency(x) for x in value]
+    with contextlib.suppress(TypeError):
         if issubclass(value, Node):
             value = value.load()
-    except TypeError:
-        # value is not a class
-        pass
-    if isinstance(value, Node) and log_warning:
-        log.warning(
-            f"DeprecationWarning: Found Node instance ({value}) in dvc.deps(), please use"
-            " zn.deps() instead."
-        )
     return value
+
+
+def update_gitignore(prefix) -> None:
+    """Add 'nodes/<prefix>_*' to the gitignore file, if not already there."""
+    ignore = f"nodes/{prefix}_*"
+
+    repo = git.Repo(".")
+    if repo.ignored(ignore):
+        return
+
+    gitignore = pathlib.Path(".gitignore")
+    with gitignore.open("a", encoding="utf-8") as file:
+        file.write("\n# ZnTrack operating directory \n")
+        file.write(f"{ignore}\n")
